==> yy-formulas-1.0.7.tgz: package/es/components/FunctionComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';

var FunctionComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(FunctionComponents, _React$Component);

  function FunctionComponents(props) {
    var _this;

    _classCallCheck(this, FunctionComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FunctionComponents).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onClick = _this.onClick.bind(_assertThisInitialized(_this));
    _this.onDoubleClick = _this.onDoubleClick.bind(_assertThisInitialized(_this));
    _this.onButClick = _this.onButClick.bind(_assertThisInitialized(_this));
    _this.state = {
      value: '',
      activeIndex: 0,
      data: _this.props.FunctionData.length > 0 ? _extends([], _this.props.FunctionData[0].formulas) : []
    };
    return _this;
  }

  _createClass(FunctionComponents, [{
    key: "onChange",
    value: function onChange(event) {
      this.setState({
        value: event.target.value
      });
    }
  }, {
    key: "onClick",
    value: function onClick(type, item, index) {
      if (type === 'big') {
        this.setState({
          activeIndex: index,
          data: _extends([], item.formulas)
        });
      }

      if (type === 'small') {
        this.props.onDesc(item.code);
      }
    }
  }, {
    key: "onDoubleClick",
    value: function onDoubleClick(item) {
      this.props.onInsertValue(' ' + item.value + ' ');
      this.props.onDesc(item.code);
    }
  }, {
    key: "onButClick",
    value: function onButClick() {
      var _this2 = this;

      if (!this.state.value) return false;
      var searchIndex = [];
      this.props.FunctionData.forEach(function (item, index) {
        var regexp = new RegExp(_this2.state.value, 'igm');

        if (regexp.test(item.name)) {
          searchIndex.push(index);
        }
      });
      if (searchIndex.length === 0) return false;
      var activeIndex = this.state.activeIndex;
      var index2 = searchIndex.indexOf(this.state.activeIndex);

      if (index2 == -1) {
        activeIndex = searchIndex[0];
      } else {
        if (searchIndex[index2 + 1]) {
          activeIndex = searchIndex[index2 + 1];
        } else {
          activeIndex = searchIndex[0];
        }
      }

      this.setState({
        activeIndex: activeIndex,
        data: _extends([], this.props.FunctionData[activeIndex].formulas)
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var FunctionData = this.props.FunctionData;
      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("div", {
        className: "function-warp"
      }, React.createElement("div", {
        className: "row"
      }, React.createElement("div", {
        className: "col-xs-5 col-sm-5 col-md-5 col-lg-5 function-left"
      }, React.createElement("form", {
        className: "form-inline"
      }, React.createElement("span", null, this.props.item.positionName), React.createElement("div", {
        className: "form-group"
      }, React.createElement("input", {
        className: "form-control",
        onChange: this.onChange,
        value: this.state.value
      })), React.createElement("button", {
        style: {
          marginLeft: '10px'
        },
        className: "btn btn-default",
        onClick: this.onButClick,
        type: "button"
      }, this.props.item.okName)), React.createElement("ul", {
        className: "nav nav-pills nav-stacked",
        style: {
          padding: '15px'
        }
      }, FunctionData.map(function (item, index) {
        return React.createElement("li", {
          key: item.code,
          onClick: _this3.onClick.bind(_this3, 'big', item, index),
          className: index === _this3.state.activeIndex ? 'active' : ''
        }, React.createElement("a", {
          href: "javascript:void(0)"
        }, item.name));
      }))), React.createElement("div", {
        className: "col-xs-7 col-sm-7 col-md-7 col-lg-7 function-right"
      }, React.createElement("div", {
        className: "list-group"
      }, this.state.data.map(function (item) {
        return React.createElement("li", {
          key: item.code,
          className: item.disabled ? 'list-group-item disabled' : 'list-group-item',
          onClick: _this3.onClick.bind(_this3, 'small', item),
          onDoubleClick: _this3.onDoubleClick.bind(_this3, item)
        }, React.createElement("a", {
          href: "javascript:void(0)"
        }, item.code));
      }))))));
    }
  }]);

  return FunctionComponents;
}(React.Component);

FunctionComponents.propTypes = {
  item: PropTypes.object,
  FunctionData: PropTypes.array
};
FunctionComponents.defaultProps = {
  item: {},
  FunctionData: []
};
polyfill(FunctionComponents);
export default FunctionComponents;

==> yy-formulas-1.0.14.tgz: package/es/components/FunctionComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';

var FunctionComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(FunctionComponents, _React$Component);

  function FunctionComponents(props) {
    var _this;

    _classCallCheck(this, FunctionComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FunctionComponents).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onClick = _this.onClick.bind(_assertThisInitialized(_this));
    _this.onDoubleClick = _this.onDoubleClick.bind(_assertThisInitialized(_this));
    _this.onButClick = _this.onButClick.bind(_assertThisInitialized(_this));
    _this.state = {
      value: '',
      activeIndex: 0,
      data: _this.props.FunctionData.length > 0 ? _extends([], _this.props.FunctionData[0].formulas) : []
    };
    return _this;
  }

  _createClass(FunctionComponents, [{
    key: "onChange",
    value: function onChange(event) {
      this.setState({
        value: event.target.value
      });
    }
  }, {
    key: "onClick",
    value: function onClick(type, item, index) {
      if (type === 'big') {
        this.setState({
          activeIndex: index,
          data: _extends([], item.formulas)
        });
      }

      if (type === 'small') {
        this.props.onDesc(item.code);
      }
    }
  }, {
    key: "onDoubleClick",
    value: function onDoubleClick(item) {
      this.props.onInsertValue(' ' + item.showvalue + ' ');
      this.props.onDesc(item.code);
    }
  }, {
    key: "onButClick",
    value: function onButClick() {
      var _this2 = this;

      if (!this.state.value) return false;
      var searchIndex = [];
      this.props.FunctionData.forEach(function (item, index) {
        var regexp = new RegExp(_this2.state.value, 'igm');

        if (regexp.test(item.name)) {
          searchIndex.push(index);
        }
      });
      if (searchIndex.length === 0) return false;
      var activeIndex = this.state.activeIndex;
      var index2 = searchIndex.indexOf(this.state.activeIndex);

      if (index2 == -1) {
        activeIndex = searchIndex[0];
      } else {
        if (searchIndex[index2 + 1]) {
          activeIndex = searchIndex[index2 + 1];
        } else {
          activeIndex = searchIndex[0];
        }
      }

      this.setState({
        activeIndex: activeIndex,
        data: _extends([], this.props.FunctionData[activeIndex].formulas)
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var FunctionData = this.props.FunctionData;
      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("div", {
        className: "function-warp"
      }, React.createElement("div", {
        className: "row"
      }, React.createElement("div", {
        className: "col-xs-5 col-sm-5 col-md-5 col-lg-5 function-left"
      }, React.createElement("form", {
        className: "form-inline"
      }, React.createElement("span", null, this.props.item.positionName), React.createElement("div", {
        className: "form-group"
      }, React.createElement("input", {
        className: "form-control",
        onChange: this.onChange,
        value: this.state.value
      })), React.createElement("button", {
        style: {
          marginLeft: '10px'
        },
        className: "btn btn-default",
        onClick: this.onButClick,
        type: "button"
      }, this.props.item.okName)), React.createElement("ul", {
        className: "nav nav-pills nav-stacked",
        style: {
          padding: '15px'
        }
      }, FunctionData.map(function (item, index) {
        return React.createElement("li", {
          key: item.code,
          onClick: _this3.onClick.bind(_this3, 'big', item, index),
          className: index === _this3.state.activeIndex ? 'active' : ''
        }, React.createElement("a", {
          href: "javascript:void(0)"
        }, item.name));
      }))), React.createElement("div", {
        className: "col-xs-7 col-sm-7 col-md-7 col-lg-7 function-right"
      }, React.createElement("div", {
        className: "list-group"
      }, this.state.data.map(function (item) {
        return React.createElement("li", {
          key: item.code,
          className: item.disabled ? 'list-group-item disabled' : 'list-group-item',
          onClick: _this3.onClick.bind(_this3, 'small', item),
          onDoubleClick: _this3.onDoubleClick.bind(_this3, item)
        }, React.createElement("a", {
          href: "javascript:void(0)"
        }, item.code));
      }))))));
    }
  }]);

  return FunctionComponents;
}(React.Component);

FunctionComponents.propTypes = {
  item: PropTypes.object,
  FunctionData: PropTypes.array
};
FunctionComponents.defaultProps = {
  item: {},
  FunctionData: []
};
polyfill(FunctionComponents);
export default FunctionComponents;
